@@ -19,6 +19,7 @@ import com.milaboratory.core.alignment.Aligner;
 import com.milaboratory.core.alignment.Alignment;
 import com.milaboratory.core.alignment.LinearGapAlignmentScoring;
 import com.milaboratory.core.mutations.MutationType;
+import com.milaboratory.core.mutations.Mutations;
 import com.milaboratory.core.mutations.generator.UniformMutationsGenerator;
 import com.milaboratory.core.sequence.NucleotideSequence;
 import com.milaboratory.core.sequence.SequencesUtils;
@@ -309,7 +310,7 @@ public class BitapPatternTest {
     }
 
     @Test
-    public void testRandomMMIndelLast1() throws Exception {
+    public void testRandomMMIndelLast1() {
         RandomGenerator rg = new Well19937c();
         long seed = rg.nextLong();
         rg = new Well19937c(seed);
@@ -320,9 +321,11 @@ public class BitapPatternTest {
             NucleotideSequence seq = TestUtil.randomSequence(NucleotideSequence.ALPHABET, rg, 5, 60);
 
             NucleotideSequence seqM = seq;
-            int muts = 1 + rg.nextInt(Math.min(10, seq.size()));
-            for (int j = 0; j < muts; ++j)
-                seqM = UniformMutationsGenerator.createUniformMutationAsObject(seqM, rg).mutate(seqM);
+            int muts = 1 + rg.nextInt(Math.min(10, seq.size() - 1));
+            for (int j = 0; j < muts; ++j) {
+                Mutations<NucleotideSequence> mutation = UniformMutationsGenerator.createUniformMutationAsObject(seqM, rg);
+                seqM = mutation.mutate(seqM);
+            }
 
             NucleotideSequence seqLeft = TestUtil.randomSequence(NucleotideSequence.ALPHABET, rg, 0, 40);
             NucleotideSequence seqRight = TestUtil.randomSequence(NucleotideSequence.ALPHABET, rg, 0, 40);
